# (c) 2023 Christophe Gueneau
from time import sleep_ms

class Mpu6050():
    def __init__(self, i2c):
        self._i2c = i2c 
        self._adr_i2c = 0x68                                     # Adresse I2C par défaut
        self._i2c.writeto(self._adr_i2c, bytes((107, 0)))  
               
    def octets_vers_entier(self, octet1, octet2):
        if octet1 & 0b1000000 == 0:                              # test si nombre positif
            return octet1 << 8 | octet2
        return - (((octet1 ^ 255) << 8) | (octet2 ^ 255) + 1)    # ^ 255 = xor 255 = complément à 1

    def lecture(self):
        valeurs_lues = self._i2c.readfrom_mem(self._adr_i2c, 0x3B, 14)
        mesures = {}
        # -32768 to 32767
        mesures["AcX"] = self.octets_vers_entier(valeurs_lues[0], valeurs_lues[1])
        mesures["AcY"] = self.octets_vers_entier(valeurs_lues[2], valeurs_lues[3])
        mesures["AcZ"] = self.octets_vers_entier(valeurs_lues[4], valeurs_lues[5])
        mesures["Tmp"] = self.octets_vers_entier(valeurs_lues[6], valeurs_lues[7]) / 340.00 + 36.53
        mesures["GyX"] = self.octets_vers_entier(valeurs_lues[8], valeurs_lues[9])
        mesures["GyY"] = self.octets_vers_entier(valeurs_lues[10], valeurs_lues[11])
        mesures["GyZ"] = self.octets_vers_entier(valeurs_lues[12], valeurs_lues[13])
        return mesures  


if __name__ == '__main__':
    from pi_pico_mpu6050 import *
    from machine import Pin, I2C
    from time import sleep_ms
   
    # Crée un objet I2C
    i2c0 = I2C(0, scl=Pin(9), sda=Pin(8), freq=400000)    # I2C0 utilisé  

    # Crée un objet Mpu6050
    mpu = Mpu6050(i2c0)
    
    while True:
        val=mpu.lecture()
        print(val)
        print(val["AcX"])
        sleep_ms(100)
        
        
        

